| as.vector.torch_tensor | R Documentation |
torch_tensor to a vectoras.vector.torch_tensor attempts to coerce a torch_tensor into a vector of
mode mode (the default is to coerce to whichever vector mode is most convenient):
if the result is atomic all attributes are removed.
## S3 method for class 'torch_tensor' as.vector(x, mode = "any")
x |
( |
mode |
( |
A vector of desired type. All attributes are removed from the result if it is of an atomic mode, but not in general for a list result.
base::as.vector
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.