dict_size: Return size of categorical variables in the data.frame

View source: R/categorical.R

dict_sizeR Documentation

Return size of categorical variables in the data.frame

Description

Return size of categorical variables in the data.frame

Usage

dict_size(data)

Arguments

data

(data.frame) A data.frame containing categorical variables. The function automatically finds categorical variables, calling internally is_categorical function.

Value

Named logical vector

Examples

glimpse(tiny_m5)
dict_size(tiny_m5)

# We can choose only the features we want - otherwise it automatically
# selects logical, factor, character or integer vectors

tiny_m5 %>%
  select(store_id, event_name_1) %>%
  dict_size()


krzjoa/torchts documentation built on June 24, 2022, 5:30 a.m.